@@ -38,6 +38,12 @@ FAILEDOPERATION_APIERROR = 'FailedOperation.ApiError'
 # The API is being manipulated. Please try again later.
 FAILEDOPERATION_APIINOPERATION = 'FailedOperation.ApiInOperation'
 
+# 
+FAILEDOPERATION_BACKENDDOMAINERROR = 'FailedOperation.BackendDomainError'
+
+# 
+FAILEDOPERATION_CAMEXCEPTION = 'FailedOperation.CamException'
+
 # An error occurred while binding a certificate.
 FAILEDOPERATION_CERTIFICATEIDBINDERROR = 'FailedOperation.CertificateIdBindError'
 
@@ -113,9 +119,6 @@ FAILEDOPERATION_EBERROR = 'FailedOperation.EbError'
 # The domain name format is incorrect.
 FAILEDOPERATION_FORMATERROR = 'FailedOperation.FormatError'
 
-# Failed to generate the API documentation.
-FAILEDOPERATION_GENERATEAPIDOCUMENTERROR = 'FailedOperation.GenerateApiDocumentError'
-
 # Failed to get the role. Please make sure that relevant API Gateway service APIs have been authorized.
 FAILEDOPERATION_GETROLEERROR = 'FailedOperation.GetRoleError'
 
@@ -164,6 +167,9 @@ INTERNALERROR = 'InternalError'
 # API Gateway internal request error. Please try again later. If the problem persists, please contact the smart customer service or submit a ticket.
 INTERNALERROR_APIGWEXCEPTION = 'InternalError.ApigwException'
 
+# 
+INTERNALERROR_CAMEXCEPTION = 'InternalError.CamException'
+
 # CAuth internal request error. Please try again later. If the problem persists, please submit a ticket.
 INTERNALERROR_CAUTHEXCEPTION = 'InternalError.CauthException'
 
@@ -173,6 +179,9 @@ INTERNALERROR_CLBEXCEPTION = 'InternalError.ClbException'
 # OSS internal request error. Please try again. If the problem persists, please contact the smart customer service or submit a ticket.
 INTERNALERROR_OSSEXCEPTION = 'InternalError.OssException'
 
+# 
+INTERNALERROR_RETURNABLEEXCEPTION = 'InternalError.ReturnableException'
+
 # SCF internal request error. Please try again. If the problem persists, please contact the smart customer service or submit a ticket.
 INTERNALERROR_SCFEXCEPTION = 'InternalError.ScfException'
 
@@ -239,9 +248,6 @@ INVALIDPARAMETERVALUE_INVALIDENVSTATUS = 'InvalidParameterValue.InvalidEnvStatus
 # The parameter value is incorrect.
 INVALIDPARAMETERVALUE_INVALIDFILTERNOTSUPPORTEDNAME = 'InvalidParameterValue.InvalidFilterNotSupportedName'
 
-# The `GenLanguage` parameter value is incorrect.
-INVALIDPARAMETERVALUE_INVALIDGENLANGUAGE = 'InvalidParameterValue.InvalidGenLanguage'
-
 # The value of the backend address parameter is incorrect.
 INVALIDPARAMETERVALUE_INVALIDIPADDRESS = 'InvalidParameterValue.InvalidIPAddress'
 
@@ -446,15 +452,24 @@ UNSUPPORTEDOPERATION_ACCOUNTARREARS = 'UnsupportedOperation.AccountArrears'
 # The key has already been bound to a usage plan.
 UNSUPPORTEDOPERATION_ALREADYBINDUSAGEPLAN = 'UnsupportedOperation.AlreadyBindUsagePlan'
 
+# 
+UNSUPPORTEDOPERATION_APILISTNOTEMPTY = 'UnsupportedOperation.ApiListNotEmpty'
+
 # The current plugin cannot be bound.
 UNSUPPORTEDOPERATION_ATTACHPLUGIN = 'UnsupportedOperation.AttachPlugin'
 
 # You are using the basic edition and only one API can be created.
 UNSUPPORTEDOPERATION_BASICSERVICENOMOREAPI = 'UnsupportedOperation.BasicServiceNoMoreApi'
 
+# 
+UNSUPPORTEDOPERATION_BASICSERVICENOTALLOWATTACHPLUGIN = 'UnsupportedOperation.BasicServiceNotAllowAttachPlugin'
+
 # Invalid log query period
 UNSUPPORTEDOPERATION_CLSSEARCHTIME = 'UnsupportedOperation.ClsSearchTime'
 
+# 
+UNSUPPORTEDOPERATION_EXISTINGONLINEENVIRONMENT = 'UnsupportedOperation.ExistingOnlineEnvironment'
+
 # Cannot force HTTPS when the protocol is HTTP.
 UNSUPPORTEDOPERATION_FORCEHTTPS = 'UnsupportedOperation.ForceHttps'
 
@@ -485,6 +500,9 @@ UNSUPPORTEDOPERATION_NOUSAGEPLANENV = 'UnsupportedOperation.NoUsagePlanEnv'
 # Network types cannot be reduced.
 UNSUPPORTEDOPERATION_REDUCENETTYPES = 'UnsupportedOperation.ReduceNetTypes'
 
+# 
+UNSUPPORTEDOPERATION_REQUESTPOSTERROR = 'UnsupportedOperation.RequestPostError'
+
 # The resource has been associated. Please disassociate it first.
 UNSUPPORTEDOPERATION_RESOURCEASSOCIATED = 'UnsupportedOperation.ResourceAssociated'
 
@@ -494,9 +512,15 @@ UNSUPPORTEDOPERATION_RESOURCEISINUSE = 'UnsupportedOperation.ResourceIsInUse'
 # The resource is not associated.
 UNSUPPORTEDOPERATION_RESOURCEUNASSOCIATED = 'UnsupportedOperation.ResourceUnassociated'
 
+# 
+UNSUPPORTEDOPERATION_TAGSNOTEMPTY = 'UnsupportedOperation.TagsNotEmpty'
+
 # The current `Uin` is not in the manual key allowlist.
 UNSUPPORTEDOPERATION_UINNOTINWHITELIST = 'UnsupportedOperation.UinNotInWhiteList'
 
+# 
+UNSUPPORTEDOPERATION_UNPACKERROR = 'UnsupportedOperation.UnpackError'
+
 # The key has already been bound to a usage plan.
 UNSUPPORTEDOPERATION_UNSUPPORTEDBINDAPIKEY = 'UnsupportedOperation.UnsupportedBindApiKey'
 
