@@ -46,7 +46,7 @@ class CfsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def CreateAutoSnapshotPolicy(self, request):
@@ -69,7 +69,7 @@ class CfsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def CreateCfsFileSystem(self, request):
@@ -92,7 +92,7 @@ class CfsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def CreateCfsPGroup(self, request):
@@ -115,7 +115,7 @@ class CfsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def CreateCfsRule(self, request):
@@ -138,7 +138,7 @@ class CfsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def CreateCfsSnapshot(self, request):
@@ -161,7 +161,31 @@ class CfsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def CreateMigrationTask(self, request):
+        """This API is used to create a migration task.
+        To use this API, submit a ticket for us to add you to the allowlist.
+
+        :param request: Request instance for CreateMigrationTask.
+        :type request: :class:`tencentcloud.cfs.v20190719.models.CreateMigrationTaskRequest`
+        :rtype: :class:`tencentcloud.cfs.v20190719.models.CreateMigrationTaskResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateMigrationTask", params, headers=headers)
+            response = json.loads(body)
+            model = models.CreateMigrationTaskResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DeleteAutoSnapshotPolicy(self, request):
@@ -184,7 +208,7 @@ class CfsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DeleteCfsFileSystem(self, request):
@@ -207,7 +231,7 @@ class CfsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DeleteCfsPGroup(self, request):
@@ -230,7 +254,7 @@ class CfsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DeleteCfsRule(self, request):
@@ -253,7 +277,7 @@ class CfsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DeleteCfsSnapshot(self, request):
@@ -276,7 +300,31 @@ class CfsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DeleteMigrationTask(self, request):
+        """This API is used to delete a migration task.
+        To use this API, submit a ticket for us to add you to the allowlist.
+
+        :param request: Request instance for DeleteMigrationTask.
+        :type request: :class:`tencentcloud.cfs.v20190719.models.DeleteMigrationTaskRequest`
+        :rtype: :class:`tencentcloud.cfs.v20190719.models.DeleteMigrationTaskResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DeleteMigrationTask", params, headers=headers)
+            response = json.loads(body)
+            model = models.DeleteMigrationTaskResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DeleteMountTarget(self, request):
@@ -299,7 +347,7 @@ class CfsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeAutoSnapshotPolicies(self, request):
@@ -322,7 +370,7 @@ class CfsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeAvailableZoneInfo(self, request):
@@ -345,7 +393,31 @@ class CfsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DescribeBucketList(self, request):
+        """This API is used to get the list of data source buckets.
+        To use this API, submit a ticket for us to add you to the allowlist.
+
+        :param request: Request instance for DescribeBucketList.
+        :type request: :class:`tencentcloud.cfs.v20190719.models.DescribeBucketListRequest`
+        :rtype: :class:`tencentcloud.cfs.v20190719.models.DescribeBucketListResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeBucketList", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeBucketListResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeCfsFileSystemClients(self, request):
@@ -368,7 +440,7 @@ class CfsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeCfsFileSystems(self, request):
@@ -391,7 +463,7 @@ class CfsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeCfsPGroups(self, request):
@@ -414,7 +486,7 @@ class CfsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeCfsRules(self, request):
@@ -437,7 +509,7 @@ class CfsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeCfsServiceStatus(self, request):
@@ -460,7 +532,7 @@ class CfsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeCfsSnapshotOverview(self, request):
@@ -483,7 +555,7 @@ class CfsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeCfsSnapshots(self, request):
@@ -506,7 +578,31 @@ class CfsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DescribeMigrationTasks(self, request):
+        """This API is used to get the list of migration tasks.
+        To use this API, submit a ticket for us to add you to the allowlist.
+
+        :param request: Request instance for DescribeMigrationTasks.
+        :type request: :class:`tencentcloud.cfs.v20190719.models.DescribeMigrationTasksRequest`
+        :rtype: :class:`tencentcloud.cfs.v20190719.models.DescribeMigrationTasksResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeMigrationTasks", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeMigrationTasksResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeMountTargets(self, request):
@@ -529,7 +625,7 @@ class CfsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeSnapshotOperationLogs(self, request):
@@ -552,7 +648,53 @@ class CfsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def ModifyFileSystemAutoScaleUpRule(self, request):
+        """This API is used to modify the scaling policy of a file system.
+
+        :param request: Request instance for ModifyFileSystemAutoScaleUpRule.
+        :type request: :class:`tencentcloud.cfs.v20190719.models.ModifyFileSystemAutoScaleUpRuleRequest`
+        :rtype: :class:`tencentcloud.cfs.v20190719.models.ModifyFileSystemAutoScaleUpRuleResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ModifyFileSystemAutoScaleUpRule", params, headers=headers)
+            response = json.loads(body)
+            model = models.ModifyFileSystemAutoScaleUpRuleResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def ScaleUpFileSystem(self, request):
+        """This API is used to scale up a Turbo file system.
+
+        :param request: Request instance for ScaleUpFileSystem.
+        :type request: :class:`tencentcloud.cfs.v20190719.models.ScaleUpFileSystemRequest`
+        :rtype: :class:`tencentcloud.cfs.v20190719.models.ScaleUpFileSystemResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ScaleUpFileSystem", params, headers=headers)
+            response = json.loads(body)
+            model = models.ScaleUpFileSystemResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def SignUpCfsService(self, request):
@@ -575,7 +717,31 @@ class CfsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def StopMigrationTask(self, request):
+        """This API is used to stop a migration task.
+        To use this API, submit a ticket for us to add you to the allowlist.
+
+        :param request: Request instance for StopMigrationTask.
+        :type request: :class:`tencentcloud.cfs.v20190719.models.StopMigrationTaskRequest`
+        :rtype: :class:`tencentcloud.cfs.v20190719.models.StopMigrationTaskResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("StopMigrationTask", params, headers=headers)
+            response = json.loads(body)
+            model = models.StopMigrationTaskResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def UnbindAutoSnapshotPolicy(self, request):
@@ -598,7 +764,7 @@ class CfsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def UpdateAutoSnapshotPolicy(self, request):
@@ -621,7 +787,7 @@ class CfsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def UpdateCfsFileSystemName(self, request):
@@ -644,7 +810,7 @@ class CfsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def UpdateCfsFileSystemPGroup(self, request):
@@ -667,7 +833,7 @@ class CfsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def UpdateCfsFileSystemSizeLimit(self, request):
@@ -690,7 +856,7 @@ class CfsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def UpdateCfsPGroup(self, request):
@@ -713,7 +879,7 @@ class CfsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def UpdateCfsRule(self, request):
@@ -736,7 +902,7 @@ class CfsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def UpdateCfsSnapshotAttribute(self, request):
@@ -759,4 +925,4 @@ class CfsClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
\ No newline at end of file
+                raise TencentCloudSDKException(type(e).__name__, str(e))
\ No newline at end of file
