@@ -145,17 +145,27 @@ class ClbClient(AbstractClient):
     def CloneLoadBalancer(self, request):
         """This API is used to create a clone of the source CLB instance with the same forwarding rules and binding relations. Note that this API is asynchronous, which means that changes to the source CLB after invocation of the API are not included in the clone.
 
-        Use limits:
-        Unsupported instance types: Classic network CLB, Classic CLB, IPv6 CLB, and NAT64 CLB.
-        Monthly subscribed CLB instances are not supported.
-        QUIC and port listeners are not supported.
-        The CLB backend service cannot be a target group or an SCF function.
-        The following settings will not be cloned automatically and require manual configuration: "Custom Configuration", "Redirection Configuration" and "Allow Traffic by Default in Security Group".
+        Limits:
+        Instance attribute restrictions
+          Only pay-as-you-go instances can be cloned. Monthly-subscribed instances cannot be cloned.
+          CLB instances without any billable items cannot be cloned.
+          Classic CLB instances and CLB u200dinstances created for Anti-DDoS service cannot be cloned.
+          Classic network-based instances cannot be cloned.
+          IPv6 instances, IPv6 NAT64 instances, and instances bound with both IPv4 and IPv6 cannot be cloned.
+          The following settings will not be cloned: **Custom configuration**, **Redirection configurations**, and **Allow Traffic by Default** in security groups.
+          Before cloning an instance, make sure all certificates used on the instance are valid. Cloning will fail if there are any expired certificates.
+        Listener restrictions
+          Instances with QUIC listeners or port range listeners cannot be cloned.
+          Private network CLB instances with TCP_SSL listeners cannot be cloned.
+          Instances with layer-7 listeners that have no forwarding rules cannot be cloned.
+          u200dInstances u200dwith more than 50 listeners cannot be cloned.
+        Backend service restrictions
+          Instances with target groups and SCF cloud functions as the backend services cannot be cloned.
 
         Notes:
         If you are using a BGP bandwidth package, you need to pass the package ID.
         To create a dedicated cluster-based CLB by cloning the source CLB, you need to pass the cluster ID. Otherwise, a normal CLB is created.
-        This API is only available for beta users. If you want to try it out, please [submit a ticket](https://console.cloud.tencent.com/workorder/category?level1_id=6&level2_id=163&source=0&data_title=%E8%B4%9F%E8%BD%BD%E5%9D%87%E8%A1%A1%20CLB&step=1).
+        This API is only available for beta users. To try it out, [submit a ticket](https://console.cloud.tencent.com/workorder/category?level1_id=6&level2_id=163&source=0&data_title=%E8%B4%9F%E8%BD%BD%E5%9D%87%E8%A1%A1%20CLB&step=1).
 
         :param request: Request instance for CloneLoadBalancer.
         :type request: :class:`tencentcloud.clb.v20180317.models.CloneLoadBalancerRequest`
@@ -1259,6 +1269,98 @@ class ClbClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def InquiryPriceCreateLoadBalancer(self, request):
+        """This API is used to query the price of creating a CLB instance.
+
+        :param request: Request instance for InquiryPriceCreateLoadBalancer.
+        :type request: :class:`tencentcloud.clb.v20180317.models.InquiryPriceCreateLoadBalancerRequest`
+        :rtype: :class:`tencentcloud.clb.v20180317.models.InquiryPriceCreateLoadBalancerResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("InquiryPriceCreateLoadBalancer", params, headers=headers)
+            response = json.loads(body)
+            model = models.InquiryPriceCreateLoadBalancerResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def InquiryPriceModifyLoadBalancer(self, request):
+        """This API is used to query the price of adjusting the specification of a CLB instance.
+
+        :param request: Request instance for InquiryPriceModifyLoadBalancer.
+        :type request: :class:`tencentcloud.clb.v20180317.models.InquiryPriceModifyLoadBalancerRequest`
+        :rtype: :class:`tencentcloud.clb.v20180317.models.InquiryPriceModifyLoadBalancerResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("InquiryPriceModifyLoadBalancer", params, headers=headers)
+            response = json.loads(body)
+            model = models.InquiryPriceModifyLoadBalancerResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def InquiryPriceRefundLoadBalancer(self, request):
+        """This API is used to query the refund amount of returning a CLB instance.
+
+        :param request: Request instance for InquiryPriceRefundLoadBalancer.
+        :type request: :class:`tencentcloud.clb.v20180317.models.InquiryPriceRefundLoadBalancerRequest`
+        :rtype: :class:`tencentcloud.clb.v20180317.models.InquiryPriceRefundLoadBalancerResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("InquiryPriceRefundLoadBalancer", params, headers=headers)
+            response = json.loads(body)
+            model = models.InquiryPriceRefundLoadBalancerResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def InquiryPriceRenewLoadBalancer(self, request):
+        """This API is used to query the price of renewing a CLB instance. It's only available to prepaid CLB instances.
+
+        :param request: Request instance for InquiryPriceRenewLoadBalancer.
+        :type request: :class:`tencentcloud.clb.v20180317.models.InquiryPriceRenewLoadBalancerRequest`
+        :rtype: :class:`tencentcloud.clb.v20180317.models.InquiryPriceRenewLoadBalancerResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("InquiryPriceRenewLoadBalancer", params, headers=headers)
+            response = json.loads(body)
+            model = models.InquiryPriceRenewLoadBalancerResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def ManualRewrite(self, request):
         """After the original access address and the address to be redirected are configured manually, the system will automatically redirect requests made to the original access address to the target address of the corresponding path. Multiple paths can be configured as a redirection policy under one domain name to achieve automatic redirection between HTTP and HTTPS. A redirection policy should meet the following rules: if A has already been redirected to B, then it cannot be redirected to C (unless the original redirection relationship is deleted and a new one is created), and B cannot be redirected to any other addresses.
 
@@ -1450,11 +1552,10 @@ class ClbClient(AbstractClient):
 
 
     def ModifyLoadBalancerSla(self, request):
-        """This API is used to upgrade a pay-as-you-go shared CLB instance to an LCU-supported CLB instance.<br/>
+        """This API is used to upgrade a pay-as-you-go shared CLB instance to an LCU-supported CLB instance. <br/>
         Limits
-        - This API can be used to upgrade only a pay-as-you-go shared instance. A monthly subscription shared instance must be upgraded in the console.
-        - An LCU-supported instance cannot be rolled back to a shared instance.
-        - LCU-supported instances are in beta testing. To upgrade to an LCU-supported instance, [submit a ticket](https://intl.cloud.tencent.com/apply/p/hf45esx99lf?from_cn_redirect=1) for application.
+        - This API can only be used to upgrade pay-as-you-go shared instances. To upgrade monthly-subscribed shared instances, please go to the CLB console.
+        - An LCU-supported instance cannot be changed back to a shared instance.
         - Classic CLB instances cannot be upgraded to LCU-supported instances.
 
         :param request: Request instance for ModifyLoadBalancerSla.
@@ -1477,6 +1578,29 @@ class ClbClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def ModifyLoadBalancersProject(self, request):
+        """This API is used to modify the projects of CLB instances.
+
+        :param request: Request instance for ModifyLoadBalancersProject.
+        :type request: :class:`tencentcloud.clb.v20180317.models.ModifyLoadBalancersProjectRequest`
+        :rtype: :class:`tencentcloud.clb.v20180317.models.ModifyLoadBalancersProjectResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ModifyLoadBalancersProject", params, headers=headers)
+            response = json.loads(body)
+            model = models.ModifyLoadBalancersProjectResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def ModifyRule(self, request):
         """This API (ModifyRule) is used to modify the attributes of a forwarding rule under a layer-7 CLB listener, such as forwarding path, health check attribute, and forwarding policy.
         This is an async API. After it is returned successfully, you can call the DescribeTaskStatus API with the returned RequestID as an input parameter to check whether this task is successful.
