@@ -35,6 +35,9 @@ INVALIDPARAMETER = 'InvalidParameter'
 # Wrong parameter format.
 INVALIDPARAMETER_FORMATERROR = 'InvalidParameter.FormatError'
 
+# Failed to query the parameter
+INVALIDPARAMETER_INVALIDFILTER = 'InvalidParameter.InvalidFilter'
+
 # Wrong CLB instance ID.
 INVALIDPARAMETER_LBIDNOTFOUND = 'InvalidParameter.LBIdNotFound'
 
