@@ -40,7 +40,7 @@ from tencentcloud.common.profile.client_profile import ClientProfile, RegionBrea
 from tencentcloud.common.sign import Sign
 from tencentcloud.common.circuit_breaker import CircuitBreaker
 
-warnings.filterwarnings("ignore")
+warnings.filterwarnings("ignore", module="tencentcloud", category=UserWarning)
 
 _json_content = 'application/json'
 _multipart_content = 'multipart/form-data'
@@ -69,9 +69,6 @@ class AbstractClient(object):
     FMT = '%(asctime)s %(process)d %(filename)s L%(lineno)s %(levelname)s %(message)s'
 
     def __init__(self, credential, region, profile=None):
-        if credential is None:
-            raise TencentCloudSDKException(
-                "InvalidCredential", "Credential is None or invalid")
         self.credential = credential
         self.region = region
         self.profile = ClientProfile() if profile is None else profile
@@ -125,7 +122,9 @@ class AbstractClient(object):
 
     def _build_req_inter(self, action, params, req_inter, options=None):
         options = options or {}
-        if self.profile.signMethod == "TC3-HMAC-SHA256" or options.get("IsMultipart") is True:
+        if options.get('SkipSign'):
+            self._build_req_without_signature(action, params, req_inter, options)
+        elif self.profile.signMethod == "TC3-HMAC-SHA256" or options.get("IsMultipart") is True:
             self._build_req_with_tc3_signature(action, params, req_inter, options)
         elif self.profile.signMethod in ("HmacSHA1", "HmacSHA256"):
             self._build_req_with_old_signature(action, params, req_inter)
@@ -254,6 +253,49 @@ class AbstractClient(object):
 
         return Sign.sign_tc3(self.credential.secret_key, date, service, string2sign)
 
+    def _build_req_without_signature(self, action, params, req, options=None):
+        content_type = self._default_content_type
+        if req.method == 'GET':
+            content_type = _form_urlencoded_content
+        elif req.method == 'POST':
+            content_type = _json_content
+        options = options or {}
+        if options.get("IsMultipart"):
+            content_type = _multipart_content
+        if options.get("IsOctetStream"):
+            content_type = _octet_stream
+        req.header["Content-Type"] = content_type
+
+        if req.method == "GET" and content_type == _multipart_content:
+            raise SDKError("ClientError",
+                           "Invalid request method GET for multipart.")
+
+        endpoint = self._get_endpoint()
+        timestamp = int(time.time())
+        req.header["Host"] = endpoint
+        req.header["X-TC-Action"] = action[0].upper() + action[1:]
+        req.header["X-TC-RequestClient"] = self._sdkVersion
+        req.header["X-TC-Timestamp"] = str(timestamp)
+        req.header["X-TC-Version"] = self._apiVersion
+        if self.profile.unsignedPayload is True:
+            req.header["X-TC-Content-SHA256"] = "UNSIGNED-PAYLOAD"
+        if self.region:
+            req.header['X-TC-Region'] = self.region
+        if self.profile.language:
+            req.header['X-TC-Language'] = self.profile.language
+
+        if req.method == 'GET':
+            params = copy.deepcopy(self._fix_params(params))
+            req.data = urlencode(params)
+        elif content_type == _json_content:
+            req.data = json.dumps(params)
+        elif content_type == _multipart_content:
+            boundary = uuid.uuid4().hex
+            req.header["Content-Type"] = content_type + "; boundary=" + boundary
+            req.data = self._get_multipart_body(params, boundary, options)
+
+        req.header["Authorization"] = "SKIP"
+
     # it must return bytes instead of string
     def _get_multipart_body(self, params, boundary, options=None):
         if options is None:
@@ -281,8 +323,8 @@ class AbstractClient(object):
         return body
 
     def _check_status(self, resp_inter):
-        if resp_inter.status != 200:
-            raise TencentCloudSDKException("ServerNetworkError", resp_inter.data)
+        if resp_inter.status_code != 200:
+            raise TencentCloudSDKException("ServerNetworkError", resp_inter.content)
 
     def _format_sign_string(self, params):
         formatParam = {}
@@ -302,35 +344,74 @@ class AbstractClient(object):
             endpoint = self._get_service_domain()
         return endpoint
 
-    def _handle_response(self, data):
-        resp = json.loads(data)
-        if "Error" in resp["Response"]:
-            code = resp["Response"]["Error"]["Code"]
-            message = resp["Response"]["Error"]["Message"]
-            reqid = resp["Response"]["RequestId"]
+    def _check_error(self, resp):
+        ct = resp.headers.get('Content-Type')
+        if ct not in ('text/plain', _json_content):
+            return
+
+        data = json.loads(resp.content)
+        if "Error" in data["Response"]:
+            code = data["Response"]["Error"]["Code"]
+            message = data["Response"]["Error"]["Message"]
+            reqid = data["Response"]["RequestId"]
             raise TencentCloudSDKException(code, message, reqid)
-        if "DeprecatedWarning" in resp["Response"]:
+        if "DeprecatedWarning" in data["Response"]:
             import warnings
             warnings.filterwarnings("default")
-            warnings.warn("This action is deprecated, detail: %s" % resp["Response"]["DeprecatedWarning"],
+            warnings.warn("This action is deprecated, detail: %s" % data["Response"]["DeprecatedWarning"],
                           DeprecationWarning)
 
-    def call(self, action, params, options=None, headers=None):
+    @staticmethod
+    def _process_response_sse(resp):
+        e = {}
+
+        for line in resp.iter_lines():
+            if not line:
+                yield e
+                e = {}
+                continue
+
+            line = line.decode('utf-8')
+
+            # comment
+            if line[0] == ':':
+                continue
+
+            colon_idx = line.find(':')
+            key = line[:colon_idx]
+            val = line[colon_idx + 1:]
+            if key == 'data':
+                # The spec allows for multiple data fields per event, concatenated them with "\n".
+                if 'data' not in e:
+                    e['data'] = val
+                else:
+                    e['data'] += '\n' + val
+            elif key in ('event', 'id'):
+                e[key] = val
+            elif key == 'retry':
+                e[key] = int(val)
+
+    def _call(self, action, params, options=None, headers=None):
         if not self.profile.disable_region_breaker:
-            return self.call_with_region_breaker(action, params, options, headers)
+            return self._call_with_region_breaker(action, params, options, headers)
         req = RequestInternal(self._get_endpoint(),
                               self.profile.httpProfile.reqMethod,
                               self._requestPath,
                               header=headers)
         self._build_req_inter(action, params, req, options)
 
-        resp_inter = self.request.send_request(req)
-        self._check_status(resp_inter)
-        data = resp_inter.data
-        self._handle_response(data)
-        return data
+        if self.profile.httpProfile.apigw_endpoint:
+            req.host = self.profile.httpProfile.apigw_endpoint
+            req.header["Host"] = req.host
+        return self.request.send_request(req)
 
-    def call_with_region_breaker(self, action, params, options=None, headers=None):
+    def call(self, action, params, options=None, headers=None):
+        resp = self._call(action, params, options, headers)
+        self._check_status(resp)
+        self._check_error(resp)
+        return resp.content
+
+    def _call_with_region_breaker(self, action, params, options=None, headers=None):
         endpoint = self._get_endpoint()
         generation, need_break = self.circuit_breaker.before_requests()
         if need_break:
@@ -340,20 +421,22 @@ class AbstractClient(object):
                               self._requestPath,
                               header=headers)
         self._build_req_inter(action, params, req, options)
-        data = '{"Response": {}}'
+        resp = None
         try:
-            resp_inter = self.request.send_request(req)
-            self._check_status(resp_inter)
-            data = resp_inter.data
-            self._handle_response(data)
+            resp = self.request.send_request(req)
             self.circuit_breaker.after_requests(generation, True)
+            return resp
         except TencentCloudSDKException as e:
-            if "RequestId" in data and e.code != "InternalError":
+            if resp and "RequestId" in resp.content and e.code != "InternalError":
                 self.circuit_breaker.after_requests(generation, True)
             else:
                 self.circuit_breaker.after_requests(generation, False)
 
-        return data
+    def call_with_region_breaker(self, action, params, options=None, headers=None):
+        resp = self._call_with_region_breaker(action, params, options, headers)
+        self._check_status(resp)
+        self._check_error(resp)
+        return resp.content
 
     def call_octet_stream(self, action, headers, body):
         """
@@ -378,22 +461,18 @@ class AbstractClient(object):
 
         req = RequestInternal(self._get_endpoint(),
                               self.profile.httpProfile.reqMethod,
-                              self._requestPath)
-        for key in headers:
-            req.header[key] = headers[key]
+                              self._requestPath,
+                              header=headers)
         req.data = body
         options = {"IsOctetStream": True}
         self._build_req_inter(action, None, req, options)
 
         resp = self.request.send_request(req)
         self._check_status(resp)
-        data = resp.data
-        self._handle_response(data)
+        self._check_error(resp)
+        return json.loads(resp.content)
 
-        json_rsp = json.loads(data)
-        return json_rsp
-
-    def call_json(self, action, params, headers=None):
+    def call_json(self, action, params, headers=None, options=None):
         """
         Call api with json object and return with json object.
 
@@ -401,12 +480,21 @@ class AbstractClient(object):
         :param action: api name e.g. ``DescribeInstances``
         :type params: dict
         :param params: params with this action
-        :type header: dict
-        :param header: request header, like {"X-TC-TraceId": "ffe0c072-8a5d-4e17-8887-a8a60252abca"}
+        :type headers: dict
+        :param headers: request header, like {"X-TC-TraceId": "ffe0c072-8a5d-4e17-8887-a8a60252abca"}
+        :type options: dict
+        :param options: request options, like {"SkipSign": False, "IsMultipart": False, "IsOctetStream": False, "BinaryParams": []}
         """
-        body = self.call(action, params, headers=headers)
-        response = json.loads(body)
-        return response
+        resp = self._call(action, params, options, headers)
+        self._check_status(resp)
+        self._check_error(resp)
+        return json.loads(resp.content)
+
+    def call_sse(self, action, params, headers=None, options=None):
+        resp = self._call(action, params, options, headers)
+        self._check_status(resp)
+        self._check_error(resp)
+        return self._process_response_sse(resp)
 
     def set_stream_logger(self, stream=None, level=logging.DEBUG, log_format=None):
         """
@@ -443,7 +531,7 @@ class AbstractClient(object):
         log = logging.getLogger(LOGGER_NAME)
         log.setLevel(level)
         mb = 1024 * 1024
-        fh = logging.handlers.RotatingFileHandler(file_path, maxBytes=512*mb, backupCount=10)
+        fh = logging.handlers.RotatingFileHandler(file_path, maxBytes=512 * mb, backupCount=10)
         fh.setLevel(level)
         if log_format is None:
             log_format = self.FMT
