@@ -72,6 +72,29 @@ class FaceidClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def ApplyWebVerificationBizTokenIntl(self, request):
+        """This API is used to apply for a BizToken before calling the web-based verification service each time. This token is required for initiating a verification process and getting the result after the verification is completed.
+
+        :param request: Request instance for ApplyWebVerificationBizTokenIntl.
+        :type request: :class:`tencentcloud.faceid.v20180301.models.ApplyWebVerificationBizTokenIntlRequest`
+        :rtype: :class:`tencentcloud.faceid.v20180301.models.ApplyWebVerificationBizTokenIntlResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ApplyWebVerificationBizTokenIntl", params, headers=headers)
+            response = json.loads(body)
+            model = models.ApplyWebVerificationBizTokenIntlResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def ApplyWebVerificationToken(self, request):
         """This API is used to apply for a token before calling the web-based verification service each time. This token is required for initiating the verification process and getting the result after the verification is completed.
 
@@ -95,6 +118,29 @@ class FaceidClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def CompareFaceLiveness(self, request):
+        """This interface supports judgment of real person and photo comparison to verify the user's identity online. By passing the video and photo into the interface, it will first judge whether the person in the video is real. If yes, it judges whether the person in the video is the same one as the uploaded photo and returns authentication result.
+
+        :param request: Request instance for CompareFaceLiveness.
+        :type request: :class:`tencentcloud.faceid.v20180301.models.CompareFaceLivenessRequest`
+        :rtype: :class:`tencentcloud.faceid.v20180301.models.CompareFaceLivenessResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CompareFaceLiveness", params, headers=headers)
+            response = json.loads(body)
+            model = models.CompareFaceLivenessResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def CreateUploadUrl(self, request):
         """This API is used to generate a temporary `UploadUrl` for uploading resource files (with the `HTTP PUT` method). After resource upload, `ResourceUrl` will be passed to the `TargetAction` API to complete the resource passing (specific fields vary by case).
         The data will be stored in a COS bucket in the region specified by the parameter `Region` for two hours.
@@ -282,6 +328,29 @@ class FaceidClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def GetWebVerificationResultIntl(self, request):
+        """This API is used to get the verification result with the corresponding BizToken after the u200dweb-based verification is completed. The token is valid for three days (259,200s) after issuance and can be called multiple times.
+
+        :param request: Request instance for GetWebVerificationResultIntl.
+        :type request: :class:`tencentcloud.faceid.v20180301.models.GetWebVerificationResultIntlRequest`
+        :rtype: :class:`tencentcloud.faceid.v20180301.models.GetWebVerificationResultIntlResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("GetWebVerificationResultIntl", params, headers=headers)
+            response = json.loads(body)
+            model = models.GetWebVerificationResultIntlResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def LivenessCompare(self, request):
         """This API is used to pass in a video and a photo, determine whether the person in the video is real, and if yes, then determine whether the person in the video is the same as that in the photo.
         This API on the legacy version will continue to serve existing users but will be unavailable to new users. We recommend you use `VideoLivenessCompare` for better service quality.
