@@ -47,6 +47,9 @@ INVALIDPARAMETER_NAME = 'InvalidParameter.Name'
 # Failed to find the channel/input/output.
 INVALIDPARAMETER_NOTFOUND = 'InvalidParameter.NotFound'
 
+# 
+INVALIDPARAMETER_OUTPUTGROUPS = 'InvalidParameter.OutputGroups'
+
 # Invalid `PageNum`.
 INVALIDPARAMETER_PAGENUM = 'InvalidParameter.PageNum'
 
@@ -59,5 +62,8 @@ INVALIDPARAMETER_POINTS = 'InvalidParameter.Points'
 # Invalid protocol.
 INVALIDPARAMETER_PROTOCOL = 'InvalidParameter.Protocol'
 
+# 
+INVALIDPARAMETER_SSAIINFO = 'InvalidParameter.SSAIInfo'
+
 # Invalid `Url`.
 INVALIDPARAMETER_URL = 'InvalidParameter.Url'
