@@ -107,6 +107,9 @@ INVALIDPARAMETERVALUE_DEFINITIONS = 'InvalidParameterValue.Definitions'
 # Incorrect parameter value: the default template cannot be deleted.
 INVALIDPARAMETERVALUE_DELETEDEFAULTTEMPLATE = 'InvalidParameterValue.DeleteDefaultTemplate'
 
+# 
+INVALIDPARAMETERVALUE_DESTINATIONLANGUAGE = 'InvalidParameterValue.DestinationLanguage'
+
 # Invalid switch value used to prohibit transcoding from low bitrate to high bitrate.
 INVALIDPARAMETERVALUE_DISABLEHIGHERVIDEOBITRATE = 'InvalidParameterValue.DisableHigherVideoBitrate'
 
@@ -230,6 +233,9 @@ INVALIDPARAMETERVALUE_SESSIONIDTOOLONG = 'InvalidParameterValue.SessionIdTooLong
 # Invalid parameter: incorrect audio channel system.
 INVALIDPARAMETERVALUE_SOUNDSYSTEM = 'InvalidParameterValue.SoundSystem'
 
+# 
+INVALIDPARAMETERVALUE_SOURCELANGUAGE = 'InvalidParameterValue.SourceLanguage'
+
 # Source file error.
 INVALIDPARAMETERVALUE_SRCFILE = 'InvalidParameterValue.SrcFile'
 
