@@ -26,15 +26,48 @@ FAILEDOPERATION_CERTIFICATEHASEXPIRED = 'FailedOperation.CertificateHasExpired'
 # The certificate does not exist.
 FAILEDOPERATION_CERTIFICATENOTFOUND = 'FailedOperation.CertificateNotFound'
 
+# Syntax error in the condition expression of the configuration file.
+FAILEDOPERATION_CONFIGCONDITIONSYNTAXERROR = 'FailedOperation.ConfigConditionSyntaxError'
+
+# Unrecognized condition matching type.
+FAILEDOPERATION_CONFIGCONDITIONUNKNOWNTARGET = 'FailedOperation.ConfigConditionUnknownTarget'
+
+# The value field of the condition expression cannot be empty in the configuration file.
+FAILEDOPERATION_CONFIGCONDITIONVALUEEMPTYERROR = 'FailedOperation.ConfigConditionValueEmptyError'
+
+# The configuration file contains fields with inconsistent data types.
+FAILEDOPERATION_CONFIGFIELDTYPEERROR = 'FailedOperation.ConfigFieldTypeError'
+
+# Syntax error in the configuration file.
+FAILEDOPERATION_CONFIGFORMATERROR = 'FailedOperation.ConfigFormatError'
+
+# Incorrect format of the configuration file. Parsing failed.
+FAILEDOPERATION_CONFIGMALFORMEDCONTENT = 'FailedOperation.ConfigMalformedContent'
+
+# Parameter verification error in the configuration file.
+FAILEDOPERATION_CONFIGPARAMVALIDATEERRORS = 'FailedOperation.ConfigParamValidateErrors'
+
+# The specified field in the configuration file is not recognized, indicating a possible spelling error or incorrect placement within the file structure.
+FAILEDOPERATION_CONFIGUNKNOWNFIELD = 'FailedOperation.ConfigUnknownField'
+
+# The current configuration file version is not supported.
+FAILEDOPERATION_CONFIGUNSUPPORTEDFORMATVERSION = 'FailedOperation.ConfigUnsupportedFormatVersion'
+
 # Insufficient account balance
 FAILEDOPERATION_INSUFFICIENTACCOUNTBALANCE = 'FailedOperation.InsufficientAccountBalance'
 
 # The site status is invalid.
 FAILEDOPERATION_INVALIDZONESTATUS = 'FailedOperation.InvalidZoneStatus'
 
+# The content is missing a mandatory configuration block.
+FAILEDOPERATION_MISSINGCONFIGCHUNK = 'FailedOperation.MissingConfigChunk'
+
 # Operation failed.
 FAILEDOPERATION_MODIFYFAILED = 'FailedOperation.ModifyFailed'
 
+# Unknown configuration group type.
+FAILEDOPERATION_UNKNOWNCONFIGGROUPTYPE = 'FailedOperation.UnknownConfigGroupType'
+
 # Internal error.
 INTERNALERROR = 'InternalError'
 
@@ -74,10 +107,13 @@ INTERNALERROR_UNKNOWERROR = 'InternalError.UnknowError'
 # Parameter error.
 INVALIDPARAMETER = 'InvalidParameter'
 
+# The regex is not in the standard RE2 format.
+INVALIDPARAMETER_ACCESSREDIRECTREGEXERROR = 'InvalidParameter.AccessRedirectRegexError'
+
 # Too many attempts. Please try again later.
 INVALIDPARAMETER_ACTIONINPROGRESS = 'InvalidParameter.ActionInProgress'
 
-# Cu200dhinese SM certificates are not supported for alias domain names.
+# Chinese SM certificates are not supported for alias domain names.
 INVALIDPARAMETER_ALIASDOMAINNOTSUPPORTSMCERT = 'InvalidParameter.AliasDomainNotSupportSMCert'
 
 # Invalid query string.
@@ -113,12 +149,21 @@ INVALIDPARAMETER_DOMAINNOTFOUND = 'InvalidParameter.DomainNotFound'
 # Traffic scheduling is already enabled for the current domain name.
 INVALIDPARAMETER_DOMAINONTRAFFICSCHEDULING = 'InvalidParameter.DomainOnTrafficScheduling'
 
+# Duplicate rules.
+INVALIDPARAMETER_DUPLICATERULE = 'InvalidParameter.DuplicateRule'
+
 # The current conditions do not support the requested operation.
 INVALIDPARAMETER_ERRACTIONUNSUPPORTTARGET = 'InvalidParameter.ErrActionUnsupportTarget'
 
 # Invalid operation.
 INVALIDPARAMETER_ERRINVALIDACTION = 'InvalidParameter.ErrInvalidAction'
 
+# Invalid operation: Duplicate operation configuration.
+INVALIDPARAMETER_ERRINVALIDACTIONDUPLICATEACTION = 'InvalidParameter.ErrInvalidActionDuplicateAction'
+
+# 
+INVALIDPARAMETER_ERRINVALIDACTIONORIGINPRIVATEADDRESS = 'InvalidParameter.ErrInvalidActionOriginPrivateAddress'
+
 # Invalid operation: Invalid parameter.
 INVALIDPARAMETER_ERRINVALIDACTIONPARAM = 'InvalidParameter.ErrInvalidActionParam'
 
@@ -188,10 +233,13 @@ INVALIDPARAMETER_ERRINVALIDCONDITIONVALUEZEROLENGTH = 'InvalidParameter.ErrInval
 # ELSE is not supported for origin server modification.
 INVALIDPARAMETER_ERRINVALIDELSEWHENMODIFYORIGINACTIONCONFIGURED = 'InvalidParameter.ErrInvalidElseWhenModifyOriginActionConfigured'
 
+# Empty condition.
+INVALIDPARAMETER_ERRNILCONDITION = 'InvalidParameter.ErrNilCondition'
+
 # To enable gRPC support, HTTP/2 support must be enabled as well.
 INVALIDPARAMETER_GRPCREQUIREHTTP2 = 'InvalidParameter.GrpcRequireHttp2'
 
-# 
+# Host header error
 INVALIDPARAMETER_HOSTHEADERINVALID = 'InvalidParameter.HostHeaderInvalid'
 
 # The domain name does not exist.
@@ -206,6 +254,9 @@ INVALIDPARAMETER_INVALIDACCELERATETYPE = 'InvalidParameter.InvalidAccelerateType
 # Invalid token authentication.
 INVALIDPARAMETER_INVALIDAUTHENTICATION = 'InvalidParameter.InvalidAuthentication'
 
+# Invalid token authentication expiration time.
+INVALIDPARAMETER_INVALIDAUTHENTICATIONTYPEEXPIRETIME = 'InvalidParameter.InvalidAuthenticationTypeExpireTime'
+
 # Invalid key for token authentication.
 INVALIDPARAMETER_INVALIDAUTHENTICATIONTYPESECRETKEY = 'InvalidParameter.InvalidAuthenticationTypeSecretKey'
 
@@ -221,7 +272,10 @@ INVALIDPARAMETER_INVALIDAUTHENTICATIONTYPETIMEPARAM = 'InvalidParameter.InvalidA
 # Invalid third-party object storage.
 INVALIDPARAMETER_INVALIDAWSPRIVATEACCESS = 'InvalidParameter.InvalidAwsPrivateAccess'
 
-# 
+# Invalid region. Please fill in a correct region of the third-party object storage service.
+INVALIDPARAMETER_INVALIDAWSREGION = 'InvalidParameter.InvalidAwsRegion'
+
+# Invalid third-party object storage.
 INVALIDPARAMETER_INVALIDAWSSECRETKEY = 'InvalidParameter.InvalidAwsSecretKey'
 
 # Invalid secondary origin domain.
@@ -263,6 +317,12 @@ INVALIDPARAMETER_INVALIDCLIENTIPHEADERNAME = 'InvalidParameter.InvalidClientIpHe
 # Invalid origin for region-specific origin-pull.
 INVALIDPARAMETER_INVALIDCLIENTIPORIGIN = 'InvalidParameter.InvalidClientIpOrigin'
 
+# Invalid conditions.
+INVALIDPARAMETER_INVALIDCONDITIONS = 'InvalidParameter.InvalidConditions'
+
+# Invalid origin-pull configuration. When `OriginType` is `COS` or `AWS_S3`, the origin address must be an object storage domain name.
+INVALIDPARAMETER_INVALIDCOSDOMAIN = 'InvalidParameter.InvalidCosDomain'
+
 # Invalid smart acceleration.
 INVALIDPARAMETER_INVALIDDYNAMICROUTINE = 'InvalidParameter.InvalidDynamicRoutine'
 
@@ -296,6 +356,9 @@ INVALIDPARAMETER_INVALIDHTTPSTLSVERSION = 'InvalidParameter.InvalidHttpsTlsVersi
 # Invalid IPv6 settings.
 INVALIDPARAMETER_INVALIDIPV6SWITCH = 'InvalidParameter.InvalidIpv6Switch'
 
+# Invalid browser cache.
+INVALIDPARAMETER_INVALIDMAXAGEFOLLOWORIGIN = 'InvalidParameter.InvalidMaxAgeFollowOrigin'
+
 # Invalid browser cache.
 INVALIDPARAMETER_INVALIDMAXAGETIME = 'InvalidParameter.InvalidMaxAgeTime'
 
@@ -305,6 +368,9 @@ INVALIDPARAMETER_INVALIDORIGIN = 'InvalidParameter.InvalidOrigin'
 # The origin cannot be a private IP or loopback address.
 INVALIDPARAMETER_INVALIDORIGINIP = 'InvalidParameter.InvalidOriginIp'
 
+# Incorrect origin server type.
+INVALIDPARAMETER_INVALIDORIGINTYPE = 'InvalidParameter.InvalidOriginType'
+
 # Invalid parameter.
 INVALIDPARAMETER_INVALIDPARAMETER = 'InvalidParameter.InvalidParameter'
 
@@ -314,10 +380,10 @@ INVALIDPARAMETER_INVALIDPOSTMAXSIZEBILLING = 'InvalidParameter.InvalidPostMaxSiz
 # Invalid POST request size.
 INVALIDPARAMETER_INVALIDPOSTSIZEVALUE = 'InvalidParameter.InvalidPostSizeValue'
 
-# AccessKeyId and SecretAccessKey u200dare required to access the third-party object storage.
+# AccessKeyId and SecretAccessKey are required to access the third-party object storage.
 INVALIDPARAMETER_INVALIDPRIVATEACCESSPARAMS = 'InvalidParameter.InvalidPrivateAccessParams'
 
-# 
+# The value of `PrivateAccess` should be `on` or `off`.
 INVALIDPARAMETER_INVALIDPRIVATEACCESSSWITCH = 'InvalidParameter.InvalidPrivateAccessSwitch'
 
 # The plan does not support QUIC.
@@ -359,12 +425,21 @@ INVALIDPARAMETER_INVALIDRULEENGINETARGETSEXTENSION = 'InvalidParameter.InvalidRu
 # Invalid URL in the rule engine condition.
 INVALIDPARAMETER_INVALIDRULEENGINETARGETSURL = 'InvalidParameter.InvalidRuleEngineTargetsUrl'
 
+# Incorrect protocol of the rules. (TCP/UDP).
+INVALIDPARAMETER_INVALIDRULEPROTO = 'InvalidParameter.InvalidRuleProto'
+
 # Invalid origin domain.
 INVALIDPARAMETER_INVALIDSERVERNAME = 'InvalidParameter.InvalidServerName'
 
+# Invalid debug configuration for EdgeOne.
+INVALIDPARAMETER_INVALIDSTANDARDDEBUG = 'InvalidParameter.InvalidStandardDebug'
+
 # Invalid client IP or CIDR block.
 INVALIDPARAMETER_INVALIDSTANDARDDEBUGCLIENTIP = 'InvalidParameter.InvalidStandardDebugClientIp'
 
+# The AllowClientIPList parameter is mandatory. The IPv4 and IPv6 network segments are supported. 0.0.0.0/0 indicates that all IPv4 clients can be debugged, and ::/0 indicates that all IPv6 clients can be debugged.
+INVALIDPARAMETER_INVALIDSTANDARDDEBUGEMPTYLIST = 'InvalidParameter.InvalidStandardDebugEmptyList'
+
 # The expiration time is exceeded.
 INVALIDPARAMETER_INVALIDSTANDARDDEBUGEXPIRETIMELIMIT = 'InvalidParameter.InvalidStandardDebugExpireTimeLimit'
 
@@ -389,6 +464,9 @@ INVALIDPARAMETER_KEYRULESINVALIDQUERYSTRINGVALUE = 'InvalidParameter.KeyRulesInv
 # Maximum parameter length exceeded.
 INVALIDPARAMETER_LENGTHEXCEEDSLIMIT = 'InvalidParameter.LengthExceedsLimit'
 
+# 
+INVALIDPARAMETER_LOADBALANCEINSTANCEIDISREQUIRED = 'InvalidParameter.LoadBalanceInstanceIdIsRequired'
+
 # Smart routing is not supported.
 INVALIDPARAMETER_MULTIPLYLAYERNOTSUPPORTSMARTROUTING = 'InvalidParameter.MultiplyLayerNotSupportSmartRouting'
 
@@ -401,15 +479,21 @@ INVALIDPARAMETER_OCDIRECTORIGINREQUIRESSMARTROUTING = 'InvalidParameter.OCDirect
 # The origin address cannot be a private IP address.
 INVALIDPARAMETER_ORIGINISINNERIP = 'InvalidParameter.OriginIsInnerIp'
 
-# 
+# The origin group name already exists.
 INVALIDPARAMETER_ORIGINNAMEEXISTS = 'InvalidParameter.OriginNameExists'
 
 # The origin group ID is required.
 INVALIDPARAMETER_ORIGINORIGINGROUPIDISREQUIRED = 'InvalidParameter.OriginOriginGroupIdIsRequired'
 
 # 
+INVALIDPARAMETER_ORIGINPULLPROTOCOLISREQUIRED = 'InvalidParameter.OriginPullProtocolIsRequired'
+
+# Incorrect origin server format. 
 INVALIDPARAMETER_ORIGINRECORDFORMATERROR = 'InvalidParameter.OriginRecordFormatError'
 
+# Incorrect key format.
+INVALIDPARAMETER_ORIGINTHIRDPARTYPARAMFORMATERROR = 'InvalidParameter.OriginThirdPartyParamFormatError'
+
 # Parameter error: Invalid “End time”. The interval between the start and end time cannot exceed 7 days.
 INVALIDPARAMETER_PARAMETERERROR = 'InvalidParameter.ParameterError'
 
@@ -419,18 +503,30 @@ INVALIDPARAMETER_PLANNOTFOUND = 'InvalidParameter.PlanNotFound'
 # Maximum upload size exceeded.
 INVALIDPARAMETER_POSTMAXSIZELIMITEXCEEDED = 'InvalidParameter.PostMaxSizeLimitExceeded'
 
-# 
+# The instance name already exists.
 INVALIDPARAMETER_PROXYNAMEDUPLICATING = 'InvalidParameter.ProxyNameDuplicating'
 
-# 
+# Incorrect origin server information format of the rules.
+INVALIDPARAMETER_RULEORIGINFORMATERROR = 'InvalidParameter.RuleOriginFormatError'
+
+# The origin of the rule does not support multiple domain names.
 INVALIDPARAMETER_RULEORIGINMULTIDOMAIN = 'InvalidParameter.RuleOriginMultiDomain'
 
-# 
+# The origin port of the rule must be an integer.
 INVALIDPARAMETER_RULEORIGINPORTINTEGER = 'InvalidParameter.RuleOriginPortInteger'
 
-# 
+# Invalid origin in the rule.
+INVALIDPARAMETER_RULEORIGINVALUEERROR = 'InvalidParameter.RuleOriginValueError'
+
+# The rule port already exists.
 INVALIDPARAMETER_RULEPORTDUPLICATING = 'InvalidParameter.RulePortDuplicating'
 
+# Incorrect port number segment of the rules.
+INVALIDPARAMETER_RULEPORTGROUP = 'InvalidParameter.RulePortGroup'
+
+# The port number of the rules must be an integer.
+INVALIDPARAMETER_RULEPORTINTEGER = 'InvalidParameter.RulePortInteger'
+
 # Invalid parameter.
 INVALIDPARAMETER_SECURITY = 'InvalidParameter.Security'
 
@@ -440,6 +536,9 @@ INVALIDPARAMETER_SETTINGINVALIDPARAM = 'InvalidParameter.SettingInvalidParam'
 # Shield Space is not bound with an origin. 
 INVALIDPARAMETER_SPACENOTBINDORIGIN = 'InvalidParameter.SpaceNotBindOrigin'
 
+# Invalid status code in cache.
+INVALIDPARAMETER_STATUSCODECACHEINVALIDSTATUSCODE = 'InvalidParameter.StatusCodeCacheInvalidStatusCode'
+
 # Resource error
 INVALIDPARAMETER_TARGET = 'InvalidParameter.Target'
 
@@ -485,7 +584,7 @@ INVALIDPARAMETERVALUE_CONTENTSAMEASNAME = 'InvalidParameterValue.ContentSameAsNa
 # The specified domain name does not match the site. 
 INVALIDPARAMETERVALUE_DOMAINNOTMATCHZONE = 'InvalidParameterValue.DomainNotMatchZone'
 
-# 
+# Invalid alias domain suffix. This domain is for internal usage and cannot be used as the alias domain.
 INVALIDPARAMETERVALUE_INVALIDALIASNAMESUFFIX = 'InvalidParameterValue.InvalidAliasNameSuffix'
 
 # Incorrect DNS record.
@@ -533,9 +632,21 @@ LIMITEXCEEDED_QUERYTIMELIMITEXCEEDED = 'LimitExceeded.QueryTimeLimitExceeded'
 # Reached the API rate limit.
 LIMITEXCEEDED_RATELIMITEXCEEDED = 'LimitExceeded.RateLimitExceeded'
 
+# The number of rules has reached the limit.
+LIMITEXCEEDED_RULELIMITEXCEEDED = 'LimitExceeded.RuleLimitExceeded'
+
+# Limit exceeded
+LIMITEXCEEDED_SECURITY = 'LimitExceeded.Security'
+
+# 
+LIMITEXCEEDED_USERQUOTALIMITED = 'LimitExceeded.UserQuotaLimited'
+
 # Reached the upper limit of sites of the plan
 LIMITEXCEEDED_ZONEBINDPLAN = 'LimitExceeded.ZoneBindPlan'
 
+# Missing parameters.
+MISSINGPARAMETER = 'MissingParameter'
+
 # Operation denied.
 OPERATIONDENIED = 'OperationDenied'
 
@@ -545,12 +656,15 @@ OPERATIONDENIED_ACCELERATEMAINLANDDISABLE = 'OperationDenied.AccelerateMainlandD
 # Cross-MLC-border acceleration and IPv6 cannot be configured at the same time.
 OPERATIONDENIED_ACCELERATEMAINLANDIPV6CONFLICT = 'OperationDenied.AccelerateMainlandIpv6Conflict'
 
-# 
+# An L7 DNS service referencing the origin group is being deployed. Please edit later.
 OPERATIONDENIED_ACCELERATIONDOMAINSTATUSNOTINONLINE = 'OperationDenied.AccelerationDomainStatusNotInOnline'
 
 # The configuration is locked. Please unlock and try again.
 OPERATIONDENIED_CONFIGLOCKED = 'OperationDenied.ConfigLocked'
 
+# 
+OPERATIONDENIED_DELETEZONEPRECHECKFAILED = 'OperationDenied.DeleteZonePreCheckFailed'
+
 # The EdgeOne service of the site is being disabled. Please try again later.
 OPERATIONDENIED_DISABLEZONENOTCOMPLETED = 'OperationDenied.DisableZoneNotCompleted'
 
@@ -566,6 +680,12 @@ OPERATIONDENIED_DOMAINNOICP = 'OperationDenied.DomainNoICP'
 # Unable to modify the service area: There are domain names under the site.
 OPERATIONDENIED_DOMAINNUMBERISNOTZERO = 'OperationDenied.DomainNumberIsNotZero'
 
+# Some domain names on the site are currently experiencing instability. The stable states for domain names are "online" and "offline".
+OPERATIONDENIED_DOMAINSTATUSUNSTABLE = 'OperationDenied.DomainStatusUnstable'
+
+# 
+OPERATIONDENIED_ENVNOTREADY = 'OperationDenied.EnvNotReady'
+
 # The EdgeOne service of the site is disabled. Please enable it and try again.
 OPERATIONDENIED_ERRZONEISALREADYPAUSED = 'OperationDenied.ErrZoneIsAlreadyPaused'
 
@@ -590,7 +710,7 @@ OPERATIONDENIED_L4STATUSNOTINONLINE = 'OperationDenied.L4StatusNotInOnline'
 # The EdgeOne service cannot be disabled for the site: An accelerated domain name is being deployed.
 OPERATIONDENIED_L7HOSTINPROCESSSTATUS = 'OperationDenied.L7HostInProcessStatus'
 
-# 
+# The site status does not support operations on load balancers.
 OPERATIONDENIED_LOADBALANCINGZONEISNOTACTIVE = 'OperationDenied.LoadBalancingZoneIsNotActive'
 
 # Unable to switch to NS for multiple sites using CNAME.
@@ -605,13 +725,19 @@ OPERATIONDENIED_NODOMAINACCESSZONEONLYALLOWMODIFIEDTOCNAME = 'OperationDenied.No
 # You can only switch a site connected without a domain name to connecting via the CNAME. Other operations are not allowed.
 OPERATIONDENIED_NODOMAINACCESSZONEONLYSUPPORTMODIFYTYPE = 'OperationDenied.NoDomainAccessZoneOnlySupportModifyType'
 
-# 
+# The current user is not included in the whitelist for version management.
+OPERATIONDENIED_NOTINVERSIONCONTROLWHITELIST = 'OperationDenied.NotInVersionControlWhiteList'
+
+# Failed to delete: The acceleration domain name is in use. 
 OPERATIONDENIED_ORIGINGROUPACCELERATIONDOMAINUSED = 'OperationDenied.OriginGroupAccelerationDomainUsed'
 
+# Ownership verification failed. Please complete the site ownership verification first.
+OPERATIONDENIED_OWNERSHIPVERIFICATIONNOTPASSED = 'OperationDenied.OwnershipVerificationNotPassed'
+
 # The specified plan does not support changing the service area of the site.
 OPERATIONDENIED_PLANNOTSUPPORTMODIFYZONEAREA = 'OperationDenied.PlanNotSupportModifyZoneArea'
 
-# 
+# This site is using Anycast IP scheduling mode and does not support Cross-MLC-border acceleration. 
 OPERATIONDENIED_PLATTYPEIPACCELERATEMAINLANDNOTSUPPORT = 'OperationDenied.PlatTypeIPAccelerateMainlandNotSupport'
 
 # The DNS record cannot be added.
@@ -626,12 +752,24 @@ OPERATIONDENIED_SHAREDCNAMEUNSUPPORTEDACCELERATEMAINLAND = 'OperationDenied.Shar
 # The domain name is bound with a shared CNAME and cannot be changed to "IPv6 access". Please unbind the domain name from the shared CNAME first.
 OPERATIONDENIED_SHAREDCNAMEUNSUPPORTEDIPV6 = 'OperationDenied.SharedCNAMEUnsupportedIPv6'
 
+# There is a test version in use. Please release the test version to the live environment, or roll back the test version and try again.
+OPERATIONDENIED_VERSIONCONTROLISGRAYING = 'OperationDenied.VersionControlIsGraying'
+
+# 
+OPERATIONDENIED_VERSIONCONTROLLOCKED = 'OperationDenied.VersionControlLocked'
+
+# The specified site working mode is not applicable to the version management mode.
+OPERATIONDENIED_WORKMODENOTINVERSIONCONTROL = 'OperationDenied.WorkModeNotInVersionControl'
+
 # The shared CNAME has been bound to another site. Please unbind first.
 OPERATIONDENIED_ZONEISBINDINGSHAREDCNAME = 'OperationDenied.ZoneIsBindingSharedCNAME'
 
-# 
+# Error found in the associated custom error page. Please unbind it first.
 OPERATIONDENIED_ZONEISREFERENCECUSTOMERRORPAGE = 'OperationDenied.ZoneIsReferenceCustomErrorPage'
 
+# The zone is disabled.
+OPERATIONDENIED_ZONENOTACTIVE = 'OperationDenied.ZoneNotActive'
+
 # The resource is occupied.
 RESOURCEINUSE = 'ResourceInUse'
 
@@ -680,6 +818,9 @@ RESOURCEINUSE_OTHERSNS = 'ResourceInUse.OthersNS'
 # Resources occupied by this account and others via CNAME.
 RESOURCEINUSE_SELFANDOTHERSCNAME = 'ResourceInUse.SelfAndOthersCname'
 
+# Unable to delete the shared CNAME: It is bound to an acceleration domain name. Please remove the binding first.
+RESOURCEINUSE_SHAREDCNAME = 'ResourceInUse.SharedCNAME'
+
 # The alias domain name is already added.
 RESOURCEINUSE_ZONE = 'ResourceInUse.Zone'
 
@@ -692,6 +833,9 @@ RESOURCENOTFOUND = 'ResourceNotFound'
 # Maximum upload size is not configured.
 RESOURCENOTFOUND_POSTMAXSIZEQUOTANOTFOUND = 'ResourceNotFound.PostMaxSizeQuotaNotFound'
 
+# The configuration group version does not exist. Please check and try again.
+RESOURCENOTFOUND_VERSIONNOTFOUND = 'ResourceNotFound.VersionNotFound'
+
 # The resource is unavailable.
 RESOURCEUNAVAILABLE = 'ResourceUnavailable'
 
@@ -704,6 +848,9 @@ RESOURCEUNAVAILABLE_DOMAINALREADYEXISTS = 'ResourceUnavailable.DomainAlreadyExis
 # The requested accelerated domain name doesn’t exist. 
 RESOURCEUNAVAILABLE_DOMAINNOTFOUND = 'ResourceUnavailable.DomainNotFound'
 
+# 
+RESOURCEUNAVAILABLE_FUNCTIONNOTFOUND = 'ResourceUnavailable.FunctionNotFound'
+
 # The domain name does not exist or not use a proxy.
 RESOURCEUNAVAILABLE_HOSTNOTFOUND = 'ResourceUnavailable.HostNotFound'
 
