@@ -53,6 +53,9 @@ FAILEDOPERATION_MEDIATYPE = 'FailedOperation.MediaType'
 # Network error.
 FAILEDOPERATION_NETWORKERROR = 'FailedOperation.NetWorkError'
 
+# No need to reduce the bitrate.
+FAILEDOPERATION_NONEEDTOREDUCEMEDIABITRATE = 'FailedOperation.NoNeedToReduceMediaBitrate'
+
 # Operation failed: the parent category ID does not exist.
 FAILEDOPERATION_PARENTIDNOFOUND = 'FailedOperation.ParentIdNoFound'
 
@@ -254,6 +257,9 @@ INVALIDPARAMETERVALUE_ENDTIME = 'InvalidParameterValue.EndTime'
 # Incorrect parameter: the end time is invalid.
 INVALIDPARAMETERVALUE_ENDTIMEOFFSET = 'InvalidParameterValue.EndTimeOffset'
 
+# Duplicate name
+INVALIDPARAMETERVALUE_EXISTEDNAME = 'InvalidParameterValue.ExistedName'
+
 # Incorrect parameter value: incorrect `ExpireTime` format.
 INVALIDPARAMETERVALUE_EXPIRETIME = 'InvalidParameterValue.ExpireTime'
 
@@ -599,7 +605,7 @@ LIMITEXCEEDED_KEYFRAMEDESCCOUNTREACHMAX = 'LimitExceeded.KeyFrameDescCountReachM
 # Limit exceeded: the total number of new and old tags exceeds the limit.
 LIMITEXCEEDED_TAGCOUNTREACHMAX = 'LimitExceeded.TagCountReachMax'
 
-# 
+# Limit exceeded: The number of templates exceeds the upper limit of 100. If you need more, please[Submit a ticket](https://console.tencentcloud.com/workorder/category)。
 LIMITEXCEEDED_TOOMUCHTEMPLATE = 'LimitExceeded.TooMuchTemplate'
 
 # Missing parameter.
@@ -641,6 +647,9 @@ RESOURCEUNAVAILABLE_MASTERPLAYLIST = 'ResourceUnavailable.MasterPlaylist'
 # Unauthorized operation.
 UNAUTHORIZEDOPERATION = 'UnauthorizedOperation'
 
+# 
+UNAUTHORIZEDOPERATION_DOMAINRECORDNOTVERIFIED = 'UnauthorizedOperation.DomainRecordNotVerified'
+
 # Unknown parameter error.
 UNKNOWNPARAMETER = 'UnknownParameter'
 
